%global with_selinux 1
%global modulename trafficserver
%global selinuxtype targeted

Name:           trafficserver
Version:        9.2.3
Release:        1%{?dist}
Summary:        Fast, scalable and extensible HTTP/1.1 and HTTP/2 caching proxy server

License:        ASL 2.0
URL:            https://trafficserver.apache.org/
Source0:        http://www.apache.org/dist/%{name}/%{name}-%{version}.tar.bz2
Source1:        http://www.apache.org/dist/%{name}/%{name}-%{version}.tar.bz2.asc
Source2:        https://downloads.apache.org/trafficserver/KEYS
Source3:        %{name}.service
Source4:        %{name}.sysusers
Source5:        %{name}.sysconf
Source6:        %{name}.tmpfilesd
Source7:        %{modulename}.te
Source8:        %{modulename}.if
Source9:        %{modulename}.fc

Patch0:         trafficserver-crypto-policy.patch
Patch1:         string-index-oob.patch

ExcludeArch:    %{arm} %{ix86} s390x

BuildRequires:  expat-devel hwloc-devel pcre-devel zlib-devel xz-devel brotli-devel
BuildRequires:  libcurl-devel ncurses-devel gnupg python3
BuildRequires:  gcc gcc-c++ perl-ExtUtils-MakeMaker
BuildRequires:  automake libtool
BuildRequires:  libcap-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  openssl-devel

Requires:       expat hwloc pcre xz ncurses pkgconfig
Requires:       openssl

Conflicts:      openssl-libs < 1:1.0.1h-4

Requires:       systemd
Requires(postun): systemd

%if 0%{?with_selinux}
Requires:        (%{name}-selinux = %{version}-%{release} if selinux-policy-%{selinuxtype})
%endif

%description
Traffic Server is a high-performance building block for cloud services.
It's more than just a caching proxy server; it also has support for
plugins to build large scale web applications.  Key features:

Caching - Improve your response time, while reducing server load and
bandwidth needs by caching and reusing frequently-requested web pages,
images, and web service calls.

Proxying - Easily add keep-alive, filter or anonymize content
requests, or add load balancing by adding a proxy layer.

Fast - Scales well on modern SMP hardware, handling 10s of thousands
of requests per second.

Extensible - APIs to write your own plug-ins to do anything from
modifying HTTP headers to handling ESI requests to writing your own
cache algorithm.

Proven - Handling over 400TB a day at Yahoo! both as forward and
reverse proxies, Apache Traffic Server is battle hardened.


%if 0%{?with_selinux}
%package selinux
Summary:             trafficserver SELinux policy
BuildArch:           noarch
Requires:            selinux-policy-%{selinuxtype}
Requires(post):      selinux-policy-%{selinuxtype}
BuildRequires:       selinux-policy-devel
%{?selinux_requires}

%description selinux
Trafficserver SELinux policy module
%endif


%package devel
Summary: Development files for Apache Traffic Server plugins
BuildArch:           noarch
Requires: %{name} = %{version}-%{release}

%description devel
The header files for developing plugins for Apache Traffic Server

Apache Traffic Server plugins can do anything from modifying HTTP headers to
hadling ESI requests to providing a different caching algorithm. 


%package perl
Summary: Perl bindings for Apache Traffic Server management
BuildArch:           noarch
BuildRequires:       perl-generators
Requires: %{name} = %{version}-%{release}

%description perl
A collection of Perl interfaces to manage Apache Traffic Server
installations.


%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'

%autosetup -p0

%build

%configure \
  --enable-layout=RedHat \
  --sysconfdir=%{_sysconfdir}/%{name} \
  --libdir=%{_libdir}/%{name} \
  --libexecdir=%{_libdir}/%{name}/plugins \
  --enable-experimental-plugins \
  --with-user=trafficserver --with-group=trafficserver
%make_build

%if 0%{?with_selinux}
mkdir selinux
cp -p %{SOURCE7} selinux/
cp -p %{SOURCE8} selinux/
cp -p %{SOURCE9} selinux/

make -f %{_datadir}/selinux/devel/Makefile %{modulename}.pp
bzip2 -9 %{modulename}.pp
%endif

%install
%make_install

%check

make check

%if 0%{?with_selinux}
install -D -m 0644 %{modulename}.pp.bz2 %{buildroot}%{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.bz2
install -D -p -m 0644 selinux/%{modulename}.if %{buildroot}%{_datadir}/selinux/devel/include/distributed/%{modulename}.if
%endif

install -D -m 0644 -p %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 -p %{SOURCE4} %{buildroot}%{_sysusersdir}/%{name}.conf
install -D -m 0644 -p %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -m 0644 %{SOURCE6} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m 0755 %{buildroot}/run/%{name}/

rm -f %{buildroot}%{_bindir}/trafficserver

find %{buildroot} -type f -name "*.la" -delete
find %{buildroot} -type f -name "*.a" -delete
rm -f %{buildroot}%{_libdir}/%{name}/plugin_*.so
rm -f %{buildroot}/usr/lib/debug%{_libdir}/%{name}/plugin_*.debug

mkdir -p %{buildroot}%{perl_vendorlib}
mv %{buildroot}/usr/lib/perl5/Apache %{buildroot}%{perl_vendorlib}
rm -rf %{buildroot}/usr/lib/perl5

install -D -m 0644 -p %{buildroot}%{_libdir}/%{name}/pkgconfig/%{name}.pc %{buildroot}%{_libdir}/pkgconfig/%{name}.pc
rm -rf %{buildroot}%{_libdir}/%{name}/pkgconfig

%pre
%sysusers_create_compat %{SOURCE4}

%post
%?ldconfig
%systemd_post %{name}.service
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%preun
%systemd_preun %{name}.service

%postun
%?ldconfig
%systemd_postun_with_restart %{name}.service

%if 0%{?with_selinux}
%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.bz2
%selinux_relabel_post -s %{selinuxtype}

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} %{modulename}
    %selinux_relabel_post -s %{selinuxtype}
fi
%endif

%files
%license LICENSE
%doc README.md CHANGELOG* NOTICE STATUS

%attr(0750, trafficserver, trafficserver) %dir %{_sysconfdir}/%{name}
%attr(-, trafficserver, trafficserver) %config(noreplace) %{_sysconfdir}/%{name}/body_factory
%attr(-, trafficserver, trafficserver) %config(noreplace) %{_sysconfdir}/%{name}/*.config
%attr(-, trafficserver, trafficserver) %config(noreplace) %{_sysconfdir}/%{name}/*.yaml
%attr(-, trafficserver, trafficserver) %{_sysconfdir}/%{name}/trafficserver-release

%config(noreplace) %{_sysconfdir}/sysconfig/%{name}

%{_unitdir}/%{name}.service
%{_sysusersdir}/%{name}.conf
%{_tmpfilesdir}/%{name}.conf

%{_bindir}/traffic_cache_tool
%{_bindir}/traffic_crashlog
%{_bindir}/traffic_ctl
%{_bindir}/traffic_layout
%{_bindir}/traffic_logcat
%{_bindir}/traffic_logstats
%{_bindir}/traffic_manager
%{_bindir}/traffic_server
%{_bindir}/traffic_top
%{_bindir}/traffic_via
%{_bindir}/tspush

%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/libts*.so*
%{_libdir}/%{name}/plugins/*.so

%attr(0750, trafficserver, trafficserver) %dir /var/log/%{name}
%attr(0750, trafficserver, trafficserver) %dir /run/%{name}
%attr(0750, trafficserver, trafficserver) %dir /var/cache/%{name}

%if 0%{?with_selinux}
%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.*
%{_datadir}/selinux/devel/include/distributed/%{modulename}.if
%ghost %verify(not md5 size mode mtime) %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{modulename}
%endif

%files perl
%{_mandir}/man3/Apache::TS.3pm.gz
%{_mandir}/man3/Apache::TS::AdminClient.3pm.gz
%{_mandir}/man3/Apache::TS::Config::Records.3pm.gz
%dir %{perl_vendorlib}/Apache
%{perl_vendorlib}/Apache/*


%files devel
%{_bindir}/tsxs
%{_includedir}/ts
%dir %{_includedir}/tscpp
%{_includedir}/tscpp/api
%{_includedir}/tscpp/util/
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.2.3-1
- initial build
